@@ -13,7 +13,7 @@ instance Compilable InterpreterStmt where
    type CompileResult InterpreterStmt = [Hask.Stmt]
 
 instance Compilable ModuleSpan where
-   type CompileResult ModuleSpan = Hask.Module
+   type ((CompileResult ModuleSpan)) = Hask.Module
 
 instance Compilable StatementSpan where
    type (CompileResult StatementSpan) = [Stmt]
